#ifndef NAVIGATEGLGRAPH_H
#define NAVIGATEGLGRAPH_H

#include "NavigateGlGraphData.h"
struct SuperGraph;

class NavigateGlGraph : public NavigateGlGraphData
{ 
    Q_OBJECT

public:
    NavigateGlGraph( QWidget* parent = 0, const char* name = 0, SuperGraph * =0, WFlags fl = 0 );
    ~NavigateGlGraph();

    GlGraphWidget *getGlGraphWidget() const;

public slots:
    void update();
};

#endif // NAVIGATEGLGRAPH_H
